**Example 1: 删除录制计划**



Input: 

```
tccli iotvideoindustry DeleteRecordingPlan --cli-unfold-argument  \
    --PlanId plan-xxxxx
```

Output: 
```
{
    "Response": {
        "RequestId": "d3d6f466-f2c2-44df-b78b-383ba717a3d8",
        "Status": "OK"
    }
}
```

